@@ -46,10 +46,11 @@ class FigureMaker(object):
         if xy is not None:
             pos_weights = np.ones_like(getattr(self, 'xyTS'))
         ppm = getattr(self, 'ppm', 300)
+        cmsPerBin = getattr(self, 'cmsPerBin', 3)
 
         self.RateMapMaker = RateMap(
             xy=xy, hdir=hdir, speed=speed, pos_weights=pos_weights, ppm=ppm,
-            xyInCms=False)
+            xyInCms=False, cmsPerBin=cmsPerBin)
         self.data_loaded = True
 
     def getSpikePosIndices(self, spk_times: np.array):
@@ -82,7 +83,7 @@ class FigureMaker(object):
         rmap = self.RateMapMaker.getMap(spk_weights)
         ratemap = np.ma.MaskedArray(rmap[0], np.isnan(rmap[0]), copy=True)
         x, y = np.meshgrid(rmap[1][1][0:-1], rmap[1][0][0:-1][::-1])
-        vmax = np.max(np.ravel(ratemap))
+        vmax = np.nanmax(np.ravel(ratemap))
         if ax is None:
             fig = plt.figure()
             ax = fig.add_subplot(111)
@@ -96,9 +97,10 @@ class FigureMaker(object):
     @stripAxes
     def makeSpikePathPlot(self, spk_times: np.array = None, ax=None, **kwargs):
         self.initialise()
-        if 'mec' or 'c' not in kwargs:
-            kwargs['c'] = tcols.colours[1]
-            kwargs['mec'] = tcols.colours[1]
+        if 'c' in kwargs:
+            col = kwargs.pop('c')
+        else:
+            col = tcols.colours[1]
         if ax is None:
             fig = plt.figure()
             ax = fig.add_subplot(111)
@@ -107,7 +109,8 @@ class FigureMaker(object):
         ax.invert_yaxis()
         if spk_times is not None:
             idx = self.getSpikePosIndices(spk_times)
-            ax.plot(self.xy[0, idx], self.xy[1, idx], 's', **kwargs)
+            ax.plot(
+                self.xy[0, idx], self.xy[1, idx], 's', c=col, **kwargs)
         return ax
 
     @stripAxes
@@ -478,18 +481,21 @@ class FigureMaker(object):
         Am = A.copy()
         Am[~inDict['dist_to_centre']] = np.nan
         Am = np.ma.masked_invalid(np.atleast_2d(Am))
-        ax.imshow(
-            A, cmap=plt.cm.get_cmap("gray_r"), interpolation='nearest')
+        x, y = np.meshgrid(
+            np.arange(0, np.shape(A)[0]),
+            np.arange(0, np.shape(A)[1]))
+        vmax = np.nanmax(np.ravel(A))
+        ax.pcolormesh(
+            x, y, A, cmap=plt.cm.get_cmap("gray_r"),
+            edgecolors='face', vmax=vmax, shading='auto')
         import copy
         cmap = copy.copy(plt.cm.get_cmap("jet"))
         cmap.set_bad('w', 0)
-        ax.pcolormesh(Am, cmap=cmap, edgecolors='face')
+        ax.pcolormesh(
+            x, y, Am, cmap=cmap,
+            edgecolors='face', vmax=vmax, shading='auto')
         # horizontal green line at 3 o'clock
-        ax.plot(
-            (inDict['closest_peak_coords'][0, 1], np.max(
-                inDict['closest_peak_coords'][:, 1])),
-            (inDict['closest_peak_coords'][0, 0],
-                inDict['closest_peak_coords'][0, 0]), '-g', **kwargs)
+        ax.axhline(y=np.shape(A)[0]/2, c='g')
         mag = inDict['scale'] * 0.5
         th = np.linspace(0, inDict['orientation'], 50)
         from ephysiopy.common.utils import rect
@@ -504,16 +510,11 @@ class FigureMaker(object):
                 ax.plot(
                     (inDict['dist_to_centre'].shape[1]/2, p[1]),
                     (inDict['dist_to_centre'].shape[0] / 2, p[0]), 'k', **kwargs)
-        all_ax = ax.axes
-        x_ax = all_ax.get_xaxis()
-        x_ax.set_tick_params(which='both', bottom=False, labelbottom=False,
-                             top=False)
-        y_ax = all_ax.get_yaxis()
-        y_ax.set_tick_params(which='both', left=False, labelleft=False,
-                             right=False)
-        all_ax.set_aspect('equal')
-        all_ax.set_xlim((0.5, inDict['dist_to_centre'].shape[1]-1.5))
-        all_ax.set_ylim((inDict['dist_to_centre'].shape[0]-.5, -.5))
+        ax.invert_yaxis()
+        # all_ax = ax.axes
+        # all_ax.set_aspect('equal')
+        # all_ax.set_xlim((0.5, inDict['dist_to_centre'].shape[1]-1.5))
+        # all_ax.set_ylim((inDict['dist_to_centre'].shape[0]-.5, -.5))
         return ax
     '''
     def plotDirFilteredRmaps(self, tetrode, cluster, maptype='rmap', **kwargs):
